<?php
/*
 * Options page for the Healomax Stress Assessment plugin
*/
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) 
{
	header("Location: /");
	die();
}
// Create menu link for options page
function healomax_stress_assessment_options_page() {
    add_options_page(
        'Healomax Stress Assessment Options',
        'Stress Assessment',
        'manage_options',
        'healomax_stress_assessment_options',
        'healomax_stress_assessment_options_page_html'
    );
}
add_action( 'admin_menu', 'healomax_stress_assessment_options_page' );

// Register plugin settings

function healomax_stress_assessment_register_settings() {
    register_setting( 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_settings',
        'healomax_stress_assessment_options_validate', 
        'healomax_stress_assessment_options_sanitize' );
    
    add_settings_section( 
        'healomax_stress_assessment_main', 
        'Main Settings', 
        'healomax_stress_assessment_main_section_text', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main_section_cb', 
        'healomax-stress-assessment' );
    add_settings_field( 
        'hsapservices', 
        'Services:', 
        'healomax_stress_assessment_hsapservices_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
    add_settings_field( 
        'hsapservices2', 
        '', 
        'healomax_stress_assessment_hsapservices2_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
    add_settings_field( 
        'hsapcontact_details', 
        'Contact Phone:', 
        'healomax_stress_assessment_hsapcontact_details_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
    add_settings_field( 
        'hsapcontact_details1', 
        'Contact eMail:', 
        'healomax_stress_assessment_hsapcontact_details1_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
    add_settings_field( 
        'hsapcontact_details2', 
        'Physical Address:', 
        'healomax_stress_assessment_hsapcontact_details2_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
    add_settings_field( 
        'healomax_admin_email', 
        'Admin Email', 
        'healomax_stress_assessment_healomax_admin_email_field', 
        'healomax_stress_assessment_options', 
        'healomax_stress_assessment_main' );
}
add_action( 'admin_init', 'healomax_stress_assessment_register_settings' );
add_action( 'admin_init', 'healomax_stress_assessment_settings_page' );

// Render options page HTML
function healomax_stress_assessment_options_page_html() {
    if ( !current_user_can( 'manage_options' ) ) {
        return;
    }
    ?>

<div class="wrap">
    <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
    <form action="options.php" method="post">
        <?php
            settings_fields( 'healomax_stress_assessment_options' );
            do_settings_sections( 'healomax_stress_assessment_options' );
            submit_button();
        ?>
    </form>
</div>
<?php
}

// Main section text
function healomax_stress_assessment_main_section_text() {
echo '<p>
            Customize the settings for the Healomax Stress Assessment plugin.
            <br><br><b>Below fields are not mandatory.</b>
        </p>';
}

// Services field
    function healomax_stress_assessment_hsapservices_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $hsapservices = (isset($options['hsapservices'])) ? $options['hsapservices'] : '';
    $hsapservices = substr($hsapservices, 0, 100);
    ?>
    <input type="hidden" name="hsapservices" value="<?php echo esc_attr( $hsapservices ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <textarea name="healomax_stress_assessment_options[hsapservices]" cols="50" rows="1">
    <?php echo esc_textarea( $hsapservices ); ?></textarea>
    <?php
}

// Services field
function healomax_stress_assessment_hsapservices2_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $hsapservices2 = (isset($options['hsapservices2'])) ? $options['hsapservices2'] : '';
    $hsapservices2 = substr($hsapservices2, 0, 100);
    ?>
    <input type="hidden" name="hsapservices2" value="<?php echo esc_attr( $hsapservices2 ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <textarea name="healomax_stress_assessment_options[hsapservices2]" cols="50" rows="1">
    <?php echo esc_textarea( $hsapservices2 ); ?></textarea>

    <p class="description">Enter services by your organization, separated by commas.</p>
    <?php
}

// Contact details field
function healomax_stress_assessment_hsapcontact_details_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $hsapcontact_details = (isset($options['hsapcontact_details'])) ? $options['hsapcontact_details'] : '';
    $hsapcontact_details = substr($hsapcontact_details, 0, 100);
    ?>
    <input type="hidden" name="hsapcontact_details" value="<?php echo esc_attr( $hsapcontact_details ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <textarea name="healomax_stress_assessment_options[hsapcontact_details]" cols="50" rows="1">
    <?php echo esc_textarea( $hsapcontact_details ); ?></textarea>
    
    <?php
}
// Contact details field
function healomax_stress_assessment_hsapcontact_details1_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $hsapcontact_details1 = (isset($options['hsapcontact_details1'])) ? $options['hsapcontact_details1'] : '';
    $hsapcontact_details1 = substr($hsapcontact_details1, 0, 100);
    ?>
    <input type="hidden" name="hsapcontact_details1" value="<?php echo esc_attr( $hsapcontact_details1 ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <textarea name="healomax_stress_assessment_options[hsapcontact_details1]" cols="50" rows="1">
        <?php echo esc_textarea( $hsapcontact_details1 ); ?></textarea>
    
    <?php
}
// Contact details field
function healomax_stress_assessment_hsapcontact_details2_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $hsapcontact_details2 = (isset($options['hsapcontact_details2'])) ? $options['hsapcontact_details2'] : '';
    $hsapcontact_details2 = substr($hsapcontact_details2, 0, 100);
    ?>
    <input type="hidden" name="hsapcontact_details2" value="<?php echo esc_attr( $hsapcontact_details2 ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <textarea name="healomax_stress_assessment_options[hsapcontact_details2]" cols="50" rows="1">
        <?php echo esc_textarea( $hsapcontact_details2 ); ?></textarea>
    <p class="description">
        Enter contact details: phone, email, and physical address.
    </p>
    <?php
}
//
// bg color
function healomax_stress_assessment_bg_color_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $bg_color = isset( $options['bg_color'] ) ? $options['bg_color'] : 'dark-black';
    ?>
    <table class="form-table">
        <tr valign="top">
            <th scope="row"><?php _e('Select Background Color', 'healomax-stress-assessment'); ?></th>
                <td>
                    <select name="bg_color">
                        <option value="dark-black"<?php selected( $options['bg_color'], 'dark-black' ); ?> style="background-color: #000000; color: #ffffff;">Dark Black</option>
                        <option value="light-black"<?php selected( $options['bg_color'], 'light-black' ); ?> style="background-color: #333333; color: #ffffff;">Light Black</option>
                        <option value="gray"<?php selected( $options['bg_color'], 'gray' ); ?> style="background-color: #808080; color: #ffffff;">Gray</option>
                    </select>
                </td>
        </tr>
    </table>
    <?php
}
// text color
function healomax_stress_assessment_text_color_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $text_color = isset( $options['text_color'] ) ? $options['text_color'] : 'gray';
    ?>
    <table class="form-table">
        <tr valign="top">
            <th scope="row"><?php _e('Select Text Color', 'healomax-stress-assessment'); ?></th>
                <td>
                    <select name="text_color">
                        <option value="gray"<?php selected( $options['text_color'], 'gray' ); ?> style="background-color: #808080; color: #ffffff;">Gray</option>
                        <option value="dark-black"<?php selected( $options['text_color'], 'dark-black' ); ?> style="background-color: #000000; color: #ffffff;">Dark Black</option>
                        <option value="light-black"<?php selected( $options['text_color'], 'light-black' ); ?> style="background-color: #333333; color: #ffffff;">Light Black</option>
                    </select>
                </td>
        </tr>
    </table>
    <?php
}
// Add a new field for the admin email ID in the settings page
    function healomax_stress_assessment_healomax_admin_email_field() {
    $options = get_option( 'healomax_stress_assessment_options' );
    $healomax_admin_email = (isset($options['healomax_admin_email'])) ? $options['healomax_admin_email'] : '';
    $healomax_admin_email = substr($healomax_admin_email, 0, 100);
    ?>
    <input type="hidden" name="healomax_admin_email" value="<?php echo esc_attr( $healomax_admin_email ); ?>">
    <?php wp_nonce_field('healomax_stress_assessment_options', 'healomax_stress_assessment_nonce'); ?>
    <input type="text" name="healomax_stress_assessment_options[healomax_admin_email]" value="<?php echo esc_attr( $healomax_admin_email ); ?>" />
    <?php echo esc_textarea( $healomax_admin_email ); ?>
    <p class="description">Enter Admin eMail ID</p>
    <?php
}

// Validate user input
    function healomax_stress_assessment_options_validate($input) {
    $valid = array();
    $valid['hsapservices'] = sanitize_textarea_field( $input['hsapservices'] );
    $valid['hsapservices2'] = sanitize_textarea_field( $input['hsapservices2'] );
    $valid['hsapcontact_details'] = sanitize_textarea_field( $input['hsapcontact_details'] );
    $valid['hsapcontact_details1'] = sanitize_textarea_field( $input['hsapcontact_details1'] );
    $valid['hsapcontact_details2'] = sanitize_textarea_field( $input['hsapcontact_details2'] );
    $valid['healomax_admin_email'] = esc_email_raw( $input['healomax_admin_email'] );
  
    return $valid;
}
?>